aboutsummaryrefslogtreecommitdiffstats
path: root/lib/prism/node_ext.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/prism/node_ext.rb')
-rw-r--r--lib/prism/node_ext.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/prism/node_ext.rb b/lib/prism/node_ext.rb
index 760b3d75df..08d9e9f36a 100644
--- a/lib/prism/node_ext.rb
+++ b/lib/prism/node_ext.rb
@@ -1,8 +1,8 @@
# frozen_string_literal: true
# Here we are reopening the YARP module to provide methods on nodes that aren't
# templated and are meant as convenience methods.
-module YARP
+module Prism
class FloatNode < Node
# Returns the value of the node as a Ruby Float.
def value
@@ -1,8 +1,8 @@
# frozen_string_literal: true
-# Here we are reopening the YARP module to provide methods on nodes that aren't
+# Here we are reopening the prism module to provide methods on nodes that aren't
# templated and are meant as convenience methods.